pub enum BuildStrategy {
RuntimeStamp,
CargoBuild,
}Expand description
Which build strategy was used to produce a BuildOutcome.
Variants
RuntimeStamp
The pre-built khora-runtime binary was stamped next to the
project’s pack. Cross-platform trivial.
CargoBuild
cargo build --release was invoked on the project’s Cargo.toml
to produce a custom binary that links the user’s native Rust.
Host-only.
Implementations