sanitize_binary_name

Function sanitize_binary_name 

fn sanitize_binary_name(name: &str) -> String
Replaces filesystem-unsafe characters in the project name with underscores so we can use it as a binary filename.