collect_asset_entries

Function collect_asset_entries 

pub fn collect_asset_entries(pvfs: &ProjectVfs) -> Vec<AssetEntry>
Build an AssetEntry cache from the current VFS contents. Used by the initial project open and when the user browses to a different folder at runtime.