pump

Function pump 

pub fn pump(
    pvfs_mutex: &Arc<Mutex<ProjectVfs>>,
    editor_state: &Arc<Mutex<EditorState>>,
)
Drain the project’s filesystem watcher and apply the appropriate invalidation / reindex actions. The asset browser cache is rebuilt whenever a full reindex was queued.