fn cursor_ray( camera: &Arc<Mutex<EditorCamera>>, cursor: Option<(f32, f32)>, viewport: Option<[f32; 4]>, ) -> Option<Ray>
The cursor ray for a screen position, or None when the viewport has not been laid out yet.
None