pub fn extract_inspected(world: &GameWorld, state: &mut EditorState)Expand description
Extracts inspectable component snapshots for the single selected entity.
pub fn extract_inspected(world: &GameWorld, state: &mut EditorState)Extracts inspectable component snapshots for the single selected entity.