pub fn pick_icon(i: &InspectedEntity) -> IconExpand description
Picks an Inspector header icon based on the most “interesting” component on the entity. The fallback is a cube (mesh-like).
pub fn pick_icon(i: &InspectedEntity) -> IconPicks an Inspector header icon based on the most “interesting” component on the entity. The fallback is a cube (mesh-like).